@@ -5,9 +5,15 @@ import random
 import sys
 import threading
 
-from collections import Iterable, Mapping, OrderedDict
+from collections import OrderedDict
+
+try:
+    from collections.abc import Iterable, Mapping
+except ImportError:
+    from collections import Iterable, Mapping
+
 from itertools import count, repeat
-from time import sleep
+from time import sleep, time
 
 from vine.utils import wraps
 
@@ -17,10 +23,10 @@ from kombu.five import (
 
 from .encoding import safe_repr as _safe_repr
 
-__all__ = [
+__all__ = (
     'LRUCache', 'memoize', 'lazy', 'maybe_evaluate',
     'is_list', 'maybe_list', 'dictfilter',
-]
+)
 
 KEYWORD_MARK = object()
 
@@ -293,9 +299,9 @@ def fxrangemax(start=1.0, stop=None, step=1.0, max=100.0):
         sum_ += cur
 
 
-def retry_over_time(fun, catch, args=[], kwargs={}, errback=None,
+def retry_over_time(fun, catch, args=None, kwargs=None, errback=None,
                     max_retries=None, interval_start=2, interval_step=2,
-                    interval_max=30, callback=None):
+                    interval_max=30, callback=None, timeout=None):
     """Retry the function over and over until max retries is exceeded.
 
     For each retry we sleep a for a while before we try again, this interval
@@ -316,23 +322,30 @@ def retry_over_time(fun, catch, args=[], kwargs={}, errback=None,
             which return the time in seconds to sleep next, and ``retries``
             is the number of previous retries.
         max_retries (int): Maximum number of retries before we give up.
-            If this is not set, we will retry forever.
+            If neither of this and timeout is set, we will retry forever.
+            If one of this and timeout is reached, stop.
         interval_start (float): How long (in seconds) we start sleeping
             between retries.
         interval_step (float): By how much the interval is increased for
             each retry.
         interval_max (float): Maximum number of seconds to sleep
             between retries.
+        timeout (int): Maximum seconds waiting before we give up.
     """
+    kwargs = {} if not kwargs else kwargs
+    args = [] if not args else args
     interval_range = fxrange(interval_start,
                              interval_max + interval_start,
                              interval_step, repeatlast=True)
+    end = time() + timeout if timeout else None
     for retries in count():
         try:
             return fun(*args, **kwargs)
         except catch as exc:
             if max_retries and retries >= max_retries:
                 raise
+            if end and time() > end:
+                raise
             if callback:
                 callback()
             tts = float(errback(exc, interval_range, retries) if errback
@@ -350,7 +363,8 @@ def reprkwargs(kwargs, sep=', ', fmt='{0}={1}'):
     return sep.join(fmt.format(k, _safe_repr(v)) for k, v in items(kwargs))
 
 
-def reprcall(name, args=(), kwargs={}, sep=', '):
+def reprcall(name, args=(), kwargs=None, sep=', '):
+    kwargs = {} if not kwargs else kwargs
     return '{0}({1}{2}{3})'.format(
         name, sep.join(map(_safe_repr, args or ())),
         (args and kwargs) and sep or '',
